@@ -2,7 +2,7 @@ from pythautomata.base_types.state import State
 from pythautomata.base_types.symbol import SymbolStr
 from pythautomata.base_types.alphabet import Alphabet
 from pythautomata.abstract.finite_automaton import FiniteAutomaton
-from pythautomata.model_comparators.nfa_hopcroft_karp_comparison_strategy import NFAHopcroftKarpComparisonStrategy as HopcroftKarpComparisonStrategy
+from pythautomata.model_comparators.hopcroft_karp_comparison_strategy import HopcroftKarpComparisonStrategy as HopcroftKarpComparisonStrategy
 
 binaryAlphabet = Alphabet(frozenset((SymbolStr('0'), SymbolStr('1'))))
 zero = binaryAlphabet['0']
@@ -22,7 +22,7 @@ class TomitasGrammarMods:
     get_mod_automaton_5: DeterministicFiniteAutomaton
         returns a modified version of the automaton 5 from the paper
     """
- 
+
     @staticmethod
     def get_mod_automaton_5():
         """
@@ -40,11 +40,11 @@ class TomitasGrammarMods:
         stateQ1 = State("State 1")
         stateQ2 = State("State 2")
         stateQ3 = State("State 3")
-        stateQ0.add_transition(one, stateQ1) 
-        stateQ1.add_transition(zero, stateQ2)        
-        stateQ2.add_transition(one, stateQ3)        
-        stateQ3.add_transition(zero, stateQ0) 
-        
+        stateQ0.add_transition(one, stateQ1)
+        stateQ1.add_transition(zero, stateQ2)
+        stateQ2.add_transition(one, stateQ3)
+        stateQ3.add_transition(zero, stateQ0)
+
         comparator = HopcroftKarpComparisonStrategy()
         return FiniteAutomaton(binaryAlphabet, frozenset({stateQ0}),
-                               set([stateQ1, stateQ2, stateQ3, stateQ0]), comparator, "Tomita's grammar 5 sub language automaton")
\ No newline at end of file
+                               set([stateQ1, stateQ2, stateQ3, stateQ0]), comparator, "Tomita's grammar 5 sub language automaton")
