@@ -55,4 +55,7 @@ class Sequence():
         if len(self.value) == len(other.value):
             return self.__repr__() < other.__repr__()
         else:
-            return len(self.value) < len(other.value)
\ No newline at end of file
+            return len(self.value) < len(other.value)
+
+    def __iter__(self):
+        return self.value.__iter__()
\ No newline at end of file
